@@ -22,6 +22,7 @@
 #' @param quiet logical value to indicate whether messages generated during
 #'   compilation will be suppressed, as well as the progress bar during
 #'   adaptation.
+#' @param params aditional parameters included as a list.
 #' @param ... additional arguments passed to this function.
 #'
 #' @return For each model calculated, returns a data frame of 4 elements with
@@ -41,7 +42,8 @@
 #' credibilityIntervals(models$gg, x = "model")
 #' }
 
-multiModelTP <- function (siData = siData, lambda = 2,
+multiModelTP <- function (siData = siData,
+                          lambda = 2,
                           n.chains = 2,
                           n.adapt = 20000,
                           n.iter = 20000,
@@ -60,7 +62,7 @@ multiModelTP <- function (siData = siData, lambda = 2,
 
   parallel <- NULL
 
-  if (class(siData) != "isotopeData") {
+  if (methods::is(siData)[1] != "isotopeData") {
     if (checkNames(df = siData, flag = 4)) class(siData) <- "isotopeData"
     else stop("We need an isotopeData class object")
     }
